@@ -53,7 +53,7 @@ sub make {
     my $class = delete $opts{class}
         || confess("Class name needed");
     my $name = delete $opts{name};
-    my $type = delete $opts{type};
+    my $type = delete $opts{_type};
     confess("We already have a thing named $name")
         if $self->registry_has($name);
     my $output_to = $opts{output_to};
